@@ -6,7 +6,7 @@ def conjugacy_class(element , group):
     # for each item in the group, calculate the conjugate and add
     # it to the set defined in the line above.
     for i in group.list():
-        conjugates.add((i^(-1))*element*i)
+        conjugates.add((i**(-1))*element*i)
     # return the final set of all conjugates of the element.
     return conjugates
 
@@ -21,7 +21,7 @@ def all_conjugacy_classes(group):
         # for each element of the group, add j^{-1}*i*j (remember that Sage 
         # takes this from right to left) to the conjugacy class
         for j in group.list():
-            conjugates.add((j^(-1))*i*j)
+            conjugates.add((j**(-1))*i*j)
         # if that conjugate class is not already in the list, add it.
         if conjugates not in conjugacy_classes:
             conjugacy_classes.append(conjugates)
@@ -39,7 +39,7 @@ def conjugacy_class_gens(group):
         # create a new set, that will be the conjugacy class of that element.
         conjugates = set(())
         for j in group.list():
-            conjugates.add((j^(-1))*i*j)
+            conjugates.add((j**(-1))*i*j)
         # sort that conjugacy class
         conjugates = sorted(conjugates)
         # if the conjugacy class is already found among the keys of the 
