@@ -1,5 +1,5 @@
-#!/usr/bin/env python
 
+import math
 
 def gcd(a,b):
     
@@ -19,7 +19,7 @@ def gcd(a,b):
     # while b is non zero...
     while b > 0:
         # obtain the quotient of a/b...
-        quotient = floor(a/b)
+        quotient = math.floor(a/b)
         # as well as the remainder of a/b...
         remainder = a % b
         # then, for the next step in the Euclidean Algorithm, set
@@ -58,7 +58,7 @@ def gcd_full(a: int,b: int):
     # algorithm, only this time, save all of the quotients into the list
     # that we just defined.
     while b > 0:
-        quotient = floor(a/b)
+        quotient = math.floor(a/b)
         remainder = a % b
         a = b
         b = remainder
