@@ -1,5 +1,5 @@
-#!/usr/bin/env python
-# coding: utf-8
+
+import math
 
 # # Repeated Squares
 # 
@@ -64,7 +64,7 @@ def to_binary(b: int):
         # while the quotient is nonzero...
         while q!=0:
             # find the quotient of b/2
-            q = floor(b/2)
+            q = math.floor(b/2)
             # as well as the remainder
             r = b % 2
             # take the remainder to be the digit of b in
@@ -90,7 +90,7 @@ def bin_exp(a: int, b: int, n: int):
         q = 1
         # compute b in binary and save the result in reverse in binary list
         while q!=0:
-            q = floor(b/2)
+            q = math.floor(b/2)
             r = b % 2
             binary.append(r)
             b = q
